@@ -19,6 +19,7 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KMacroExpander>
+#include <QCoreApplication>
 #include <QDir>
 
 #include "crashedapplication.h"
@@ -104,6 +105,15 @@ bool Debugger::runInTerminal() const
     }
 }
 
+QString Debugger::backendValueOfParameter(const QString &key) const
+{
+    if (!isValid() || !m_config->hasGroup(m_backend)) {
+        return QString();
+    } else {
+        return m_config->group(m_backend).readEntry(key, QString());
+    }
+}
+
 //static
 void Debugger::expandString(QString & str, ExpandStringUsage usage, const QString & tempFile)
 {
@@ -128,16 +138,23 @@ void Debugger::expandString(QString & str, ExpandStringUsage usage, const QStrin
 //static
 QList<Debugger> Debugger::availableDebuggers(const QString & path, const QString & backend)
 {
-    QString debuggerDir = QStandardPaths::locate(QStandardPaths::DataLocation, path, QStandardPaths::LocateDirectory);
-    QStringList debuggers = QDir(debuggerDir).entryList(QDir::Files);
-
+    QStringList debuggerDirs {
+        // Search in default path
+        QStandardPaths::locate(QStandardPaths::AppDataLocation, path, QStandardPaths::LocateDirectory),
+        // Search from application path, this helps when deploying an application
+        QString(QStringLiteral("%1/%2")).arg(QCoreApplication::applicationDirPath(), path)
+    };
     QList<Debugger> result;
-    foreach (const QString & debuggerFile, debuggers) {
-        Debugger debugger;
-        debugger.m_config = KSharedConfig::openConfig(debuggerDir +QLatin1Char('/')+ debuggerFile);
-        if (debugger.supportedBackends().contains(backend)) {
-            debugger.setUsedBackend(backend);
-            result.append(debugger);
+
+    for (const auto & debuggerDir: debuggerDirs) {
+        QStringList debuggers = QDir(debuggerDir).entryList(QDir::Files);
+        for (const auto & debuggerFile : debuggers) {
+            Debugger debugger;
+            debugger.m_config = KSharedConfig::openConfig(QString(QStringLiteral("%1/%2")).arg(debuggerDir, debuggerFile));
+            if (debugger.supportedBackends().contains(backend)) {
+                debugger.setUsedBackend(backend);
+                result.append(debugger);
+            }
         }
     }
     return result;
